summaryrefslogtreecommitdiff
path: root/core/arch/arm/tee/entry_std.c
diff options
context:
space:
mode:
Diffstat (limited to 'core/arch/arm/tee/entry_std.c')
-rw-r--r--core/arch/arm/tee/entry_std.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/core/arch/arm/tee/entry_std.c b/core/arch/arm/tee/entry_std.c
index 29c3b747..fb4555be 100644
--- a/core/arch/arm/tee/entry_std.c
+++ b/core/arch/arm/tee/entry_std.c
@@ -346,7 +346,8 @@ void tee_entry_std(struct thread_smc_args *smc_args)
return;
}
- thread_set_irq(true); /* Enable IRQ for STD calls */
+ /* Enable foreign interrupts for STD calls */
+ thread_set_foreign_intr(true);
switch (arg->cmd) {
case OPTEE_MSG_CMD_OPEN_SESSION:
entry_open_session(smc_args, arg, num_params);